@@ -3,6 +3,8 @@
 # email:yuyc@ishangqi.com
 # date:2022/2/17 2:45 下午
 # Copyright (C) 2022 The lesscode Team
+import asyncio
+
 import pymysql
 from dbutils.pooled_db import PooledDB
 
@@ -30,10 +32,18 @@ class MysqlPool(BaseConnectionPool):
                                               db=self.conn_info.db_name, autocommit=True,
                                               minsize=self.conn_info.min_size,
                                               maxsize=self.conn_info.max_size)
+            loop = asyncio.get_running_loop()
+            loop.create_task(self.keep_connect(pool))
             return pool
         else:
             raise NotImplementedError
 
+    async def keep_connect(self, pool):
+        while True:
+            async with pool.acquire() as conn:
+                await conn.ping()
+            await asyncio.sleep(60)
+
     def sync_create_pool(self):
         pool = PooledDB(pymysql, 5, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
                         passwd=self.conn_info.password, db=self.conn_info.db_name, charset="utf8", autocommit=True)
