@@ -4,6 +4,7 @@ from datetime import datetime, timedelta
 from lesscode.utils.aes import AES
 from tornado.options import options
 
+
 def format_company_id_en(value, route_key):
     key = options.aes_key
     if route_key in ["core.patent", "core.patent_lite"]:
@@ -137,7 +138,7 @@ def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt_or
 
 def es_condition_by_exist(bool_must_list, param, is_exists="是"):
     if param:
-        if is_exists == "是" or is_exists == "true":
+        if is_exists == "是" or is_exists == "true" or is_exists == True:
             bool_must_list.append({
                 "exists": {
                     "field": param
@@ -159,7 +160,7 @@ def es_condition_by_exist(bool_must_list, param, is_exists="是"):
 def es_condition_by_exist_or_not(bool_must_list, param_dict):
     if param_dict:
         for key in param_dict:
-            if param_dict[key] in ["是", "true"]:
+            if param_dict[key] in ["是", "true", True]:
                 bool_must_list.append({
                     "exists": {
                         "field": key
