@@ -10,22 +10,28 @@ async def post(path, data=None,
                result_type="json", pack=True, **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.post(base_url + path, json=data, **kwargs) as resp:
-            result = await resp.text()
             if result_type == "json":
-                result = json.loads(result)
+                result = await resp.json()
                 if not pack:
                     result = result.get("data")
+            elif result_type == "text":
+                result = await resp.text()
+            else:
+                result = await resp.content
             return result
 
 
 async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=True, **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.get(base_url + path, params=params, **kwargs) as resp:
-            result = await resp.text()
             if result_type == "json":
-                result = json.loads(result)
+                result = await resp.json()
                 if not pack:
                     result = result.get("data")
+            elif result_type == "text":
+                result = await resp.text()
+            else:
+                result = await resp.content
             return result
 
 
@@ -35,8 +41,10 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
         res = res.json()
         if not pack:
             res = res.get("data")
-    else:
+    elif result_type == "text":
         res = res.text
+    else:
+        res = res.content
     return res
 
 
@@ -48,8 +56,10 @@ def sync_post(path, data=None,
         res = res.json()
         if not pack:
             res = res.get("data")
-    else:
+    elif result_type == "text":
         res = res.text
+    else:
+        res = res.content
     return res
 
 
